ig.module(
    'game.entities.enemy'
).requires(
	'impact.entity',
	'game.entities.player'
).defines(function() {

    EntityEnemy = ig.Entity.extend({
		
        size: {x:16, y: 16},
        flip: false,  
		gravityFactor: 1,          
        animSheet: new ig.AnimationSheet('media/enemy.png', 16, 16),
		deathFlag: false,
		
    	// allow collision detection with other entities
		type: ig.Entity.TYPE.B,
    	checkAgainst: ig.Entity.TYPE.A,       	


		init: function(x, y){
			this.parent(x, y);
			this.addAnim('walk', 0.1, [0,1,2,1]);								
		},
		
		update: function(){
			this.parent();	
			if(this.deathFlag){
				return;
			}
					
			this.vel.x = 40 * this.turnAround() ;
			this.currentAnim.flip.x = this.flip;			
		},
		
		turnAround: function(){
			//is the next collision tile empty 
			var x = this.pos.x + (this.flip ? + 5 : this.size.x - 5);
			var y = this.pos.y + this.size.y + 5;
			if(!ig.game.collisionMap.getTile(x, y)){
				this.flip = !this.flip;
			}
			
			return this.flip ? -1 : 1;
		},
		
		handleMovementTrace: function(res){			
			if(this.deathFlag){
	            // Pass through the collision tiles
	            this.pos.x += this.vel.x * ig.system.tick;
	            this.pos.y += this.vel.y * ig.system.tick;
			}else{
				this.parent(res);
				// flip if collides with a wall
				if(res.collision.x){
					this.flip = !this.flip;
				}
			}			
		},
		
		check: function(other){
			// if player is falling and is above the enemy kill the enemy
			if(other.pos.y < this.pos.y && other.vel.y > 0){
				this.kill();
				other.vel.y = - 300;
			}else{
				// .. otherwise damage our player
				other.receiveDamage(4, this);
				this.kill();
			}			
		},
		
		
		kill: function(){
			this.deathFlag = true;
			this.checkAgainst = ig.Entity.TYPE.NONE;
			this.vel.x = 0;
			this.currentAnim.flip.y = true;
		}
										           
    });

});

	
	
			